@@ -48,7 +48,7 @@
 
 /**
  * @addtogroup Cache Page cache
- * @ingroup Service
+ * @ingroup HiDec
  */
 
 #define CACHED_MAXSUB1(pgno) vbi->vt.cached[((pgno) - 0x100) & 0x7FF]
@@ -83,9 +83,10 @@ for ((p) = PARENT((l)->head, typeof(*(p)), _node_);			\
  *
  * Does not free the list object or any nodes.
  */
-static inline void
+static __inline__ void
 destroy_list(list *l)
 {
+	l = l;
 }
 
 /**
