@@ -18,7 +18,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: caption.c,v 1.14 2003/10/21 20:53:05 mschimek Exp $ */
+/* $Id: caption.c,v 1.18 2005/01/24 00:13:39 mschimek Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,7 +33,6 @@
 #include "tables.h"
 #include "vbi.h"
 
-#define printable(c) ((((c) & 0x7F) < 0x20 || ((c) & 0x7F) > 0x7E) ? '.' : ((c) & 0x7F))
 #define elements(array) (sizeof(array) / sizeof(array[0]))
 
 #define XDS_DEBUG(x) /* x */
@@ -153,14 +152,14 @@ init_hcrc(void)
 }
 
 static int
-xds_strfu(char *d, char *s, int len)
+xds_strfu(signed char *d, const uint8_t *s, int len)
 {
 	int c, neq = 0;
 
 	for (; len > 0 && *s <= 0x20; s++, len--);
 
 	for (; len > 0; s++, len--) {
-		c = MAX((char) 0x20, *s);
+		c = MAX((uint8_t) 0x20, *s);
 		neq |= *d ^ c;
 		*d++ = c;
 	}
@@ -308,7 +307,7 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			XDS_DEBUG(
 				printf("program title: '");
 				for (i = 0; i < length; i++)
-					putchar(printable(buffer[i]));
+					putchar(vbi_printable (buffer[i]));
 				printf("'\n");
 			)
 
@@ -464,7 +463,11 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			for (i = 0; i < 2; i++) {
 				int l = (buffer[i] >> 3) & 7;
 				vbi_audio_mode m = mode[i][buffer[i] & 7];
-				const char *s = ((1 << l) & 0xC1) ? NULL : language[l];
+				/* should be const char *, but I got that
+				   wrong and cannot change the public
+				   pi->audio[].language type now. */
+				unsigned char *s = ((1 << l) & 0xC1) ? NULL :
+					(unsigned char *) language[l];
 
 				if (pi->audio[i].mode != m) {
 					neq = 1; pi->audio[i].mode = m;
@@ -581,7 +584,7 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			XDS_DEBUG(
 				printf("program descr. line %d: >", line + 1);
 				for (i = 0; i < length; i++)
-					putchar(printable(buffer[i]));
+					putchar(vbi_printable (buffer[i]));
 				printf("<\n");
 			)
 
@@ -621,7 +624,7 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			if (xds_strfu(n->name, buffer, length)) {
 				n->cycle = 1;
 			} else if (n->cycle == 1) {
-				char *s = n->name;
+				signed char *s = n->name;
 				uint32_t sum;
 
 				if (n->call[0])
@@ -647,7 +650,7 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			XDS_DEBUG(
 				printf("Network name: '");
 				for (i = 0; i < length; i++)
-					putchar(printable(buffer[i]));
+					putchar(vbi_printable (buffer[i]));
 				printf("'\n");
 			)
 
@@ -664,7 +667,7 @@ xds_decoder(vbi_decoder *vbi, int _class, int type,
 			XDS_DEBUG(
 				printf("Network call letters: '");
 				for (i = 0; i < length; i++)
-					putchar(printable(buffer[i]));
+					putchar(vbi_printable (buffer[i]));
 				printf("'\n");
 			)
 
@@ -771,8 +774,8 @@ xds_separator(vbi_decoder *vbi, uint8_t *buf)
 {
 	struct caption *cc = &vbi->cc;
 	xds_sub_packet *sp = cc->curr_sp;
-	int c1 = vbi_parity(buf[0]);
-	int c2 = vbi_parity(buf[1]);
+	int c1 = vbi_unpar8 (buf[0]);
+	int c2 = vbi_unpar8 (buf[1]);
 	unsigned int class, type;
 
 	XDS_SEP_DEBUG(printf("XDS %02x %02x\n", buf[0], buf[1]));
@@ -794,7 +797,7 @@ xds_separator(vbi_decoder *vbi, uint8_t *buf)
 		class = (c1 - 1) >> 1;
 
 		if (class > elements(cc->sub_packet)
-		    || c2 > elements(cc->sub_packet[0])) {
+		    || c2 > (int) elements(cc->sub_packet[0])) {
 			XDS_SEP_DEBUG(printf("XDS ignore packet %d/0x%02x\n", class, c2));
 			cc->curr_sp = NULL;
 			return;
@@ -832,7 +835,7 @@ xds_separator(vbi_decoder *vbi, uint8_t *buf)
 
 			XDS_SEP_DUMP(
 				for (i = 0; i < sp->count - 2; i++)
-					printf("%c", printable(sp->buffer[i]));
+					printf("%c", vbi_printable (sp->buffer[i]));
 				printf(" %d/0x%02x\n", class, type);
 			)
 		}
@@ -879,7 +882,7 @@ itv_separator(vbi_decoder *vbi, struct caption *cc, char c)
 	if (c >= 0x20) {
 		if (c == '<') // s4-nbc omitted CR
 			itv_separator(vbi, cc, 0);
-		else if (cc->itv_count > sizeof(cc->itv_buf) - 2)
+		else if (cc->itv_count > (int) sizeof(cc->itv_buf) - 2)
 			cc->itv_count = 0;
 
 		cc->itv_buf[cc->itv_count++] = c;
@@ -1436,12 +1439,12 @@ vbi_decode_caption(vbi_decoder *vbi, int line, uint8_t *buf)
 
 	case 284:	/* NTSC */
 		CC_DUMP(
-			putchar(printable(buf[0]));
-			putchar(printable(buf[1]));
+			putchar(vbi_printable (buf[0]));
+			putchar(vbi_printable (buf[1]));
 			fflush(stdout);
 		)
 
-		if (vbi_parity(buf[0]) >= 0) {
+		if (vbi_unpar8 (buf[0]) >= 0) {
 			if (c1 == 0) {
 				goto finish;
 			} else if (c1 <= 0x0F) {
@@ -1465,15 +1468,15 @@ vbi_decode_caption(vbi_decoder *vbi, int line, uint8_t *buf)
 		goto finish;
 	}
 
-	if (vbi_parity(buf[0]) < 0) {
+	if (vbi_unpar8 (buf[0]) < 0) {
 		c1 = 127;
 		buf[0] = c1; /* traditional 'bad' glyph, ccfont has */
 		buf[1] = c1; /*  room, design a special glyph? */
 	}
 
 	CC_DUMP(
-		putchar(printable(buf[0]));
-		putchar(printable(buf[1]));
+		putchar(vbi_printable (buf[0]));
+		putchar(vbi_printable (buf[1]));
 		fflush(stdout);
 	)
 
@@ -1487,7 +1490,7 @@ vbi_decode_caption(vbi_decoder *vbi, int line, uint8_t *buf)
 		break; /* XDS field 1?? */
 
 	case 0x10 ... 0x1F:
-		if (vbi_parity(buf[1]) >= 0) {
+		if (vbi_unpar8 (buf[1]) >= 0) {
 			if (!field2
 			    && buf[0] == cc->last[0]
 			    && buf[1] == cc->last[1]) {
@@ -1509,8 +1512,8 @@ vbi_decode_caption(vbi_decoder *vbi, int line, uint8_t *buf)
 
 	default:
 		CC_TEXT_DUMP(
-			putchar(printable(buf[0]));
-			putchar(printable(buf[1]));
+			putchar(vbi_printable (buf[0]));
+			putchar(vbi_printable (buf[1]));
 			fflush(stdout);
 		)
 
@@ -1539,7 +1542,7 @@ vbi_decode_caption(vbi_decoder *vbi, int line, uint8_t *buf)
 		c = ch->attr;
 
 		for (i = 0; i < 2; i++) {
-			char ci = vbi_parity(buf[i]) & 0x7F; /* 127 if bad */
+			char ci = vbi_unpar8 (buf[i]) & 0x7F; /* 127 if bad */
 
 			if (ci <= 0x1F) /* 0x00 no char, 0x01 ... 0x1F invalid */
 				continue;
