@@ -17,7 +17,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: lang.h,v 1.4 2003/02/16 21:11:27 mschimek Exp $ */
+/* $Id: lang.h,v 1.5 2005/01/19 04:23:53 mschimek Exp $ */
 
 #ifndef LANG_H
 #define LANG_H
@@ -108,7 +108,7 @@ typedef struct vbi_font_descr vbi_font_descr;
  * Mosaics and Line Drawing Set, with codes U+EE00 ... U+EFFF, and
  * Teletext DRCS coded U+F000 ... U+F7FF.
  */
-static_inline vbi_bool
+vbi_inline vbi_bool
 vbi_is_print(unsigned int unicode)
 {
 	return unicode < 0xE600;
@@ -122,7 +122,7 @@ vbi_is_print(unsigned int unicode)
  * @c TRUE if @a unicode represents a Teletext G1 Block Mosaic or G3 Smooth
  * Mosaics and Line Drawing Set, that is a code in range U+EE00 ... U+EFFF.
  */
-static_inline vbi_bool
+vbi_inline vbi_bool
 vbi_is_gfx(unsigned int unicode)
 {
 	return unicode >= 0xEE00 && unicode <= 0xEFFF;
@@ -136,7 +136,7 @@ vbi_is_gfx(unsigned int unicode)
  * @c TRUE if @a unicode represents a Teletext DRCS (Dynamically
  * Redefinable Character), that is a code in range U+F000 ... U+F7FF.
  **/
-static_inline vbi_bool
+vbi_inline vbi_bool
 vbi_is_drcs(unsigned int unicode)
 {
 	return unicode >= 0xF000;
