@@ -17,10 +17,10 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: teletext.c,v 1.15 2004/04/04 21:46:38 mschimek Exp $ */
+/* $Id: teletext.c,v 1.20 2005/01/20 01:40:15 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
-#  include "../config.h"
+#  include "config.h"
 #endif
 
 #include "site_def.h"
@@ -71,8 +71,6 @@ extern const char _zvbi_intl_domainname[];
 
 #define DEBUG 0
 
-#define printable(c) ((((c) & 0x7F) < 0x20 || ((c) & 0x7F) > 0x7E) ? \
-                      '.' : ((c) & 0x7F))
 #if DEBUG
 #define printv(templ, args...) fprintf(stderr, templ ,##args)
 #else
@@ -785,25 +783,25 @@ keyword(vbi_link *ld, uint8_t *p, int column,
 		ld->pgno = pgno;
 
 		return i + j;
-	} else if (!strncasecmp(s, "https://", i = 8)) {
+	} else if (!strncasecmp((char *) s, "https://", i = 8)) {
 		ld->type = VBI_LINK_HTTP;
-	} else if (!strncasecmp(s, "http://", i = 7)) {
+	} else if (!strncasecmp((char *) s, "http://", i = 7)) {
 		ld->type = VBI_LINK_HTTP;
-	} else if (!strncasecmp(s, "www.", i = 4)) {
+	} else if (!strncasecmp((char *) s, "www.", i = 4)) {
 		ld->type = VBI_LINK_HTTP;
-		strcpy(ld->url, "http://");
-	} else if (!strncasecmp(s, "ftp://", i = 6)) {
+		strcpy((char *) ld->url, "http://");
+	} else if (!strncasecmp((char *) s, "ftp://", i = 6)) {
 		ld->type = VBI_LINK_FTP;
 	} else if (*s == '@' || *s == 0xA7) {
 		ld->type = VBI_LINK_EMAIL;
-		strcpy(ld->url, "mailto:");
+		strcpy((char *) ld->url, "mailto:");
 		i = 1;
-	} else if (!strncasecmp(s, "(at)", i = 4)) {
+	} else if (!strncasecmp((char *) s, "(at)", i = 4)) {
 		ld->type = VBI_LINK_EMAIL;
-		strcpy(ld->url, "mailto:");
-	} else if (!strncasecmp(s, "(a)", i = 3)) {
+		strcpy((char *) ld->url, "mailto:");
+	} else if (!strncasecmp((char *) s, "(a)", i = 3)) {
 		ld->type = VBI_LINK_EMAIL;
-		strcpy(ld->url, "mailto:");
+		strcpy((char *) ld->url, "mailto:");
 	} else
 		return 1;
 
@@ -841,11 +839,11 @@ keyword(vbi_link *ld, uint8_t *p, int column,
 
 		*back = k;
 
-		strncat(ld->url, s + k, -k);
-		strcat(ld->url, "@");
-		strncat(ld->url, s + i, j);
+		strncat((char *) ld->url, (char *) s + k, -k);
+		strcat((char *) ld->url, "@");
+		strncat((char *) ld->url, (char *) s + i, j);
 	} else
-		strncat(ld->url, s + k, i + j - k);
+		strncat((char *) ld->url, (char *) s + k, i + j - k);
 
 	return i + j;
 }
@@ -940,9 +938,9 @@ vbi_resolve_link(vbi_page *pg, int column, int row, vbi_link *ld)
 
 		if (b <= 0) {
 			if (buffer[j + 1] == ')' && j > 2) {
-				if (!strncasecmp(buffer + j + 1 - 3, "(at", 3))
+				if (!strncasecmp((char *) buffer + j + 1 - 3, "(at", 3))
 					b = j - 3;
-				else if (!strncasecmp(buffer + j + 1 - 2, "(a", 2))
+				else if (!strncasecmp((char *) buffer + j + 1 - 2, "(a", 2))
 					b = j - 2;
 			} else if (buffer[j + 1] == '@' || buffer[j + 1] == 167)
 				b = j;
@@ -1198,7 +1196,7 @@ enhance(vbi_decoder *vbi, vt_magazine *mag, vt_extension *ext,
 	struct pex26 *pt, ptmp;
 	int pdc_hr;
 
-	static void
+	void
 	flush(int column)
 	{
 		int row = inv_row + active_row;
@@ -1286,7 +1284,7 @@ enhance(vbi_decoder *vbi, vt_magazine *mag, vt_extension *ext,
 				int raw;
 
 				raw = (row == 0 && i < 9) ?
-					0x20 : vbi_parity(vtp->data.lop.raw[row][i - 1]);
+					0x20 : vbi_unpar8 (vtp->data.lop.raw[row][i - 1]);
 
 				/* set-after spacing attributes cancelling non-spacing */
 
@@ -1304,7 +1302,7 @@ enhance(vbi_decoder *vbi, vt_magazine *mag, vt_extension *ext,
 
 				case 0x0A:		/* end box */
 				case 0x0B:		/* start box */
-					if (i < COLUMNS && vbi_parity(vtp->data.lop.raw[row][i]) == raw) {
+					if (i < COLUMNS && vbi_unpar8 (vtp->data.lop.raw[row][i]) == raw) {
 						printv("... boxed term %d %02x\n", i, raw);
 						mac.opacity = 0;
 					}
@@ -1323,7 +1321,7 @@ enhance(vbi_decoder *vbi, vt_magazine *mag, vt_extension *ext,
 					break;
 
 				raw = (row == 0 && i < 8) ?
-					0x20 : vbi_parity(vtp->data.lop.raw[row][i]);
+					0x20 : vbi_unpar8 (vtp->data.lop.raw[row][i]);
 
 				/* set-at spacing attributes cancelling non-spacing */
 
@@ -1358,7 +1356,7 @@ enhance(vbi_decoder *vbi, vt_magazine *mag, vt_extension *ext,
 		active_column = column;
 	}
 
-	static void
+	void
 	flush_row(void)
 	{
 		if (type == OBJ_TYPE_PASSIVE || type == OBJ_TYPE_ADAPTIVE)
@@ -2088,7 +2086,7 @@ post_enhance(vbi_page *pg, int display_rows)
 	for (row = 0; row <= last_row; row++) {
 		for (column = 0; column < COLUMNS; acp++, column++) {
 			if (1)
-				printv("%c", printable(acp->unicode));
+				printv("%c", vbi_printable (acp->unicode));
 			else
 				printv("%04xF%dB%dS%dO%d ", acp->unicode,
 				       acp->foreground, acp->background,
@@ -2314,6 +2312,7 @@ vbi_format_vt_page(vbi_decoder *vbi,
 		struct vbi_font_descr *font;
 		int mosaic_unicodes; /* 0xEE00 separate, 0xEE20 contiguous */
 		int held_mosaic_unicode;
+		int esc;
 		vbi_bool hold, mosaic;
 		vbi_bool double_height, wide_char;
 		vbi_char ac, *acp = &pg->text[row * EXT_COLUMNS];
@@ -2328,6 +2327,7 @@ vbi_format_vt_page(vbi_decoder *vbi,
 		mosaic_unicodes	= 0xEE20; /* contiguous */
 		ac.opacity	= pg->page_opacity[row > 0];
 		font		= pg->font[0];
+		esc		= 0;
 		hold		= FALSE;
 		mosaic		= FALSE;
 
@@ -2342,7 +2342,7 @@ vbi_format_vt_page(vbi_decoder *vbi,
 			if (row == 0 && column < 8) {
 				raw = buf[column];
 				i++;
-			} else if ((raw = vbi_parity(vtp->data.lop.raw[0][i++])) < 0)
+			} else if ((raw = vbi_unpar8 (vtp->data.lop.raw[0][i++])) < 0)
 				raw = ' ';
 
 			/* set-at spacing attributes */
@@ -2418,13 +2418,13 @@ vbi_format_vt_page(vbi_decoder *vbi,
 
 			case 0x0A:		/* end box */
 				if (column < (COLUMNS - 1)
-				    && vbi_parity(vtp->data.lop.raw[0][i]) == 0x0a)
+				    && vbi_unpar8 (vtp->data.lop.raw[0][i]) == 0x0a)
 					ac.opacity = pg->page_opacity[row > 0];
 				break;
 
 			case 0x0B:		/* start box */
 				if (column < (COLUMNS - 1)
-				    && vbi_parity(vtp->data.lop.raw[0][i]) == 0x0b)
+				    && vbi_unpar8 (vtp->data.lop.raw[0][i]) == 0x0b)
 					ac.opacity = pg->boxed_opacity[row > 0];
 				break;
 
@@ -2461,7 +2461,7 @@ vbi_format_vt_page(vbi_decoder *vbi,
 				break;
 
 			case 0x1B:		/* ESC */
-				font = (font == pg->font[0]) ? pg->font[1] : pg->font[0];
+				font = pg->font[esc ^= 1];
 				break;
 			}
 		}
