@@ -18,11 +18,13 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: explist.c,v 1.7 2002/11/30 02:37:18 mschimek Exp $ */
+/* $Id: explist.c,v 1.9 2004/12/31 06:05:20 mschimek Exp $ */
 
 #undef NDEBUG
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -35,7 +37,7 @@
 #endif
 #include <locale.h>
 
-#include <libzvbi.h>
+#include "src/libzvbi.h"
 
 #ifndef _
 #ifdef ENABLE_NLS
