@@ -1,7 +1,7 @@
 /*
  *  libzvbi test
  *
- *  Copyright (C) 2000, 2001, 2002 Michael H. Schimek
+ *  Copyright (C) 2000-2002, 2004 Michael H. Schimek
  *  Copyright (C) 2003 James Mastros
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -19,11 +19,13 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: osc.c,v 1.12 2004/04/03 00:09:37 mschimek Exp $ */
+/* $Id: osc.c,v 1.18 2005/01/19 04:23:53 mschimek Exp $ */
 
 #undef NDEBUG
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -35,7 +37,10 @@
 #include <getopt.h>
 #endif
 
-#include <libzvbi.h>
+#include "src/libzvbi.h"
+
+#define TEST 1
+#include "src/raw_decoder.h"	/* _vbi_service_table[] */
 
 #ifndef X_DISPLAY_MISSING
 
@@ -51,6 +56,7 @@ int			slines;
 vbi_bool		quit;
 
 int			do_sim;
+int			ignore_error;
 
 Display *		display;
 int			screen;
@@ -68,51 +74,12 @@ int			draw_row, draw_offset;
 int			draw_count = -1;
 int                     cur_x, cur_y;
 
-/* Copied from ../src/decoder.c */
-struct vbi_service_par {
-	unsigned int	id;		/* VBI_SLICED_ */
-	char *		label;
-	int		first[2];	/* scanning lines (ITU-R), max. distribution; */
-	int		last[2];	/*  zero: no data from this field, requires field sync */
-	int		offset;		/* leading edge hsync to leading edge first CRI one bit
-					    half amplitude points, nanoseconds */
-	int		cri_rate;	/* Hz */
-	int		bit_rate;	/* Hz */
-	int		scanning;	/* scanning system: 525 (FV = 59.94 Hz, FH = 15734 Hz),
-							    625 (FV = 50 Hz, FH = 15625 Hz) */
-	unsigned int	cri_frc;	/* Clock Run In and FRaming Code, LSB last txed bit of FRC */
-	unsigned int	cri_mask;	/* cri bits significant for identification, */
-	char		cri_bits;
-	char		frc_bits;	/* cri_bits at cri_rate, frc_bits at bit_rate */
-	short		payload;	/* in bits */
-	char		modulation;	/* payload modulation */
-};
-extern struct vbi_service_par vbi_services[];
-
-
 #include "sim.c"
 
-/* From capture.c */
-static inline int
-odd_parity(uint8_t c)
-{
-	c ^= (c >> 4);
-	c ^= (c >> 2);
-	c ^= (c >> 1);
-
-	return c & 1;
-}
-
-extern const int8_t vbi_hamm8val[256];
-extern const uint8_t vbi_bit_reverse[256];
-
-static inline int
-vbi_hamm16(uint8_t *p)
-{
-	return vbi_hamm8val[p[0]] | (vbi_hamm8val[p[1]] << 4);
-}
-
-#define printable(c) ((((c) & 0x7F) < 0x20 || ((c) & 0x7F) > 0x7E) ? '.' : ((c) & 0x7F))
+extern void
+vbi_capture_set_log_fp		(vbi_capture *		capture,
+				 FILE *			fp);
+extern vbi_bool vbi_capture_force_read_mode;
 
 #define PIL(day, mon, hour, min) \
 	(((day) << 15) + ((mon) << 11) + ((hour) << 6) + ((min) << 0))
@@ -139,7 +106,7 @@ decode_ttx(uint8_t *buf, int line)
         text += sprintf(text, "pg %x%02d ln %03d >", magazine, packet, line);
 
         for (j = 0; j < 42; j++) {
-	   char c = printable(buf[j]);
+	   char c = vbi_printable (buf[j]);
 	   
 	   *text = c;
 	   text++;
@@ -205,7 +172,7 @@ decode_vps(uint8_t *buf)
 
 	c &= 0x7F;
 
-	label[l] = printable(c);
+	label[l] = vbi_printable (c);
 
 	l = (l + 1) % 16;
 
@@ -299,13 +266,13 @@ draw(unsigned char *raw)
 			break;
 	if (i < slines) {
 	   int svc_idx=0;
-	   while (vbi_services[svc_idx].id !=0 && 
-		  vbi_services[svc_idx].id != sliced[i].id)
+	   while (_vbi_service_table[svc_idx].id !=0 && 
+		  _vbi_service_table[svc_idx].id != sliced[i].id)
 	     svc_idx++;
 	   
-	   if (vbi_services[svc_idx].id == sliced[i].id) {
-	      struct vbi_service_par service;
-	      service = vbi_services[svc_idx];
+	   if (_vbi_service_table[svc_idx].id == sliced[i].id) {
+	      struct _vbi_service_par service;
+	      service = _vbi_service_table[svc_idx];
 	      
 	      xti.nchars += snprintf(buf + xti.nchars, 255 - xti.nchars,
 				     " %s (%x) +%dns",
@@ -590,12 +557,20 @@ mainloop(void)
 
 		switch (r) {
 		case -1:
-			fprintf(stderr, "VBI read error: %d, %s\n",
-				errno, strerror(errno));
-			exit(EXIT_FAILURE);
+			fprintf(stderr, "VBI read error: %d, %s%s\n",
+				errno, strerror(errno),
+				ignore_error ? " (ignored)" : "");
+			if (ignore_error)
+				continue;
+			else
+				exit(EXIT_FAILURE);
 		case 0: 
-			fprintf(stderr, "VBI read timeout\n");
-			exit(EXIT_FAILURE);
+			fprintf(stderr, "VBI read timeout%s\n",
+				ignore_error ? " (ignored)" : "");
+			if (ignore_error)
+				continue;
+			else
+				exit(EXIT_FAILURE);
 		case 1:
 			break;
 		default:
@@ -610,15 +585,19 @@ mainloop(void)
 	}
 }
 
-static const char short_options[] = "d:npsv";
+static const char short_options[] = "123de:npsv";
 
 #ifdef HAVE_GETOPT_LONG
 static const struct option
 long_options[] = {
 	{ "device",	required_argument,	NULL,		'd' },
+	{ "ignore-error", no_argument,		NULL,		'e' },
 	{ "ntsc",	no_argument,		NULL,		'n' },
 	{ "pal",	no_argument,		NULL,		'p' },
 	{ "sim",	no_argument,		NULL,		's' },
+	{ "v4l",	no_argument,		NULL,		'1' },
+	{ "v4l2-read",	no_argument,		NULL,		'2' },
+	{ "v4l2-mmap",	no_argument,		NULL,		'3' },
 	{ "verbose",	no_argument,		NULL,		'v' },
 	{ 0, 0, 0, 0 }
 };
@@ -633,7 +612,9 @@ main(int argc, char **argv)
 	char *errstr;
 	unsigned int services;
 	int scanning = 625;
-	vbi_bool verbose = FALSE;
+	int strict;
+	int verbose = 0;
+	int interface = 0;
 	int c, index;
 
 	while ((c = getopt_long(argc, argv, short_options,
@@ -641,9 +622,20 @@ main(int argc, char **argv)
 		switch (c) {
 		case 0: /* set flag */
 			break;
+		case '2':
+			/* Preliminary hack for tests. */
+			vbi_capture_force_read_mode = TRUE;
+			/* fall through */
+		case '1':
+		case '3':
+			interface = c - '0';
+			break;
 		case 'd':
 			dev_name = optarg;
 			break;
+		case 'e':
+			ignore_error ^= TRUE;
+			break;
 		case 'n':
 			scanning = 525;
 			break;
@@ -654,7 +646,7 @@ main(int argc, char **argv)
 			do_sim ^= TRUE;
 			break;
 		case 'v':
-			verbose ^= TRUE;
+			++verbose;
 			break;
 		default:
 			fprintf(stderr, "Unknown option\n");
@@ -666,65 +658,78 @@ main(int argc, char **argv)
 		| VBI_SLICED_CAPTION_625 | VBI_SLICED_VPS
 		| VBI_SLICED_WSS_625 | VBI_SLICED_WSS_CPR1204;
 
+	strict = 0;
+
 	if (do_sim) {
 		par = init_sim (scanning, services);
 	} else {
 		do {
-			cap = vbi_capture_v4l2k_new (dev_name,
-						    /* fd -- dev_name is non-null, so unused */ 0,
-						    /* buffers */ 5,
-						    &services,
-						    /* strict */ -1,
-						    &errstr,
-						    /* trace */ verbose);
-			if (cap)
-				break;
+			if (1 != interface) {
+				cap = vbi_capture_v4l2k_new
+					(dev_name, /* fd */ -1,
+					 /* buffers */ 5, &services,
+					 strict, &errstr,
+					 /* trace */ !!verbose);
 
-			fprintf (stderr, "Cannot capture vbi data "
-				 "with v4l2k interface:\n%s\n", errstr);
+				if (cap)
+					break;
 
-			free (errstr);
-			cap = vbi_capture_v4l2_new (dev_name,
-						    /* buffers */ 5,
-						    &services,
-						    /* strict */ -1,
-						    &errstr,
-						    /* trace */ verbose);
-			if (cap)
-				break;
+				fprintf (stderr, "Cannot capture vbi data "
+					 "with v4l2k interface:\n%s\n",
+					 errstr);
 
-			fprintf (stderr, "Cannot capture vbi data "
-				 "with v4l2 interface:\n%s\n", errstr);
+				free (errstr);
 
-			free (errstr);
+				cap = vbi_capture_v4l2_new (dev_name,
+							    /* buffers */ 5,
+							    &services,
+							    strict,
+							    &errstr,
+							    /* trace */
+							    !!verbose);
+				if (cap)
+					break;
 
-			cap = vbi_capture_v4l_new (dev_name,
-						   scanning,
-						   &services,
-						   /* strict */ -1,
-						   &errstr,
-						   /* trace */ verbose);
-			if (cap)
-				break;
+				fprintf (stderr, "Cannot capture vbi data "
+					 "with v4l2 interface:\n%s\n", errstr);
 
-			fprintf (stderr, "Cannot capture vbi data "
-				 "with v4l interface:\n%s\n", errstr);
+				free (errstr);
+			}
 
-			free (errstr);
+			if (interface < 2) {
+				cap = vbi_capture_v4l_new (dev_name,
+							   scanning,
+							   &services,
+							   strict,
+							   &errstr,
+							   /* trace */
+							   !!verbose);
+				if (cap)
+					break;
 
-			cap = vbi_capture_bktr_new (dev_name,
-						    scanning,
-						    &services,
-						    /* strict */ -1,
-						    &errstr,
-						    /* trace */ verbose);
-			if (cap)
-				break;
+				fprintf (stderr, "Cannot capture vbi data "
+					 "with v4l interface:\n%s\n", errstr);
 
-			fprintf (stderr, "Cannot capture vbi data "
-				 "with bktr interface:\n%s\n", errstr);
+				free (errstr);
+			}
 
-			free (errstr);
+			/* BSD interface */
+			if (1) {
+				cap = vbi_capture_bktr_new (dev_name,
+							    scanning,
+							    &services,
+							    strict,
+							    &errstr,
+							    /* trace */
+							    !!verbose);
+				if (cap)
+					break;
+
+				fprintf (stderr, "Cannot capture vbi data "
+					 "with bktr interface:\n%s\n", errstr);
+
+				free (errstr);
+			}
 
 			exit(EXIT_FAILURE);
 		} while (0);
@@ -732,7 +737,11 @@ main(int argc, char **argv)
 		assert ((par = vbi_capture_parameters(cap)));
 	}
 
-	assert(par->sampling_format == VBI_PIXFMT_YUV420);
+	if (verbose > 1) {
+		vbi_capture_set_log_fp (cap, stderr);
+	}
+
+	assert (par->sampling_format == VBI_PIXFMT_YUV420);
 
 	src_w = par->bytes_per_line / 1;
 	src_h = par->count[0] + par->count[1];
